.. :changelog:

History
=======

1.0.1 (2023-10-26)
------------------
* Updated `MANIFEST.in` to include `tracery/py.typed` file to fix mypy error.


1.0.0 (2023-05-04)
------------------

* Added type hints.
* Removed `setup.py` in favor of `pyproject.toml`.
* Removed empty `requirements.txt` file.
* Removed `todo.txt`.
* Added numpy-style docstrings.
* Renamed functions to comply with python snake-case conventions.
* Changed modifier functions to private with prefixed underscore.
* Added Black as code formatter
* Added isort as import sorter

0.1.1 (2017-03-27)
------------------

* Obligatory "foreseeable mistake in setup.py" release (thx `j-e-d <https://github.com/j-e-d>`_).

0.1.0 (2017-03-27)
------------------

* Initial release on PyPI, incorporating many contributions from `hugovk
  <https://github.com/hugovk>`_.

0.0.1 (2016-03-09)
------------------

* First release on Github.
